#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Plots the dynamic support/resistance
    /// </summary>
    [Description("Plots the dynamic support/resistance")]
    [Gui.Design.DisplayName("Dynamic S/R ColorBand")]
    public class DynamicSR_ColorBand : Indicator
    {
        #region Variables
        // Wizard generated variables
        private int			period				= 21;     
        private double 		HH					=0;
		private double			LL					=0;
		// User defined variables (add any user defined variables below)
		private double		DynamicR			= 0;
		private double		DynamicS			= 0;
		
		private int			barcounter			= 0;
		
		private bool bandArea  = true;
		private Color bandAreaColor = Color.Turquoise;
		
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(new Pen(Color.Blue,1), PlotStyle.Line,"Resistance"));
			Add(new Plot(new Pen(Color.Magenta,1), PlotStyle.Line, "Support"));
			Add(new Plot(new Pen(Color.Transparent,1), PlotStyle.Line, "Average"));
			
            CalculateOnBarClose	= false;
            Overlay				= true;
            PriceTypeSupported	= false;
			PaintPriceMarkers	= true;
			AutoScale			= false;
			BarsRequired		= 1;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {	Resistance.Set(High[0]);
			Support.Set(Low[0]);
            if ( CurrentBar < Period )	return;
			Average.Set(HMA(period)[0]);
			
			if (Average[0]>Average[1])
				
			{
				HH = Math.Max(High[0],HH);
				Resistance.Set(Resistance[1]);
				Support.Set(Support[1]);
			}
			if (Average[0]<Average[1])
				
			{	
				LL=Math.Min(Low[0],LL);
				Support.Set(Support[1]);
				Resistance.Set(Resistance[1]);
			}
			
			if (Average[0] <Average[1] && Average[1]>Average[2])
				
			{
				Resistance.Set(HH);
				LL=Low[0];
			}

			if (Average[0]>Average[1] && Average[1]<Average[2])
				
			{
				Support.Set(LL);
				HH=High[0];
				
			}
		
			//Support.Set(LL);
			//Resistance.Set(HH);
			
			if(BandArea){
				//DrawRegion("Bollinger Upper Region", CurrentBar, 0, DynamicSR_Color(55).Resistance, DynamicSR_Color(55).Support, Color.Black, Color.Blue, 1);
				//DrawRegion("tag1", CurrentBar, 0, Resistance, Support, Color.Empty, Color.LimeGreen,2);
				DrawRegion("tag1", CurrentBar, 0, Resistance, Support, Color.Empty, BandAreaColor,2);
			}
		}
	

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Resistance
        {
            get { return Values[0]; }
        }
		
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Support
        {
            get { return Values[1]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries Average
        {
            get { return Values[2]; }
        }
		
		[Description("Numbers of bars used for calculations")]
		[Category("Parameters")]
		public int Period
		{
			get { return period; }
			set { period = Math.Max(1, value); }
		}
		
		[Description("Have ColorBand between support and resistance")]
		[Category("Parameters")]
		public bool BandArea
		{
			get { return bandArea; }
			set { bandArea = value; }
		}
        		
		[Description("Color of Band between support and resistance")]
		[Category("Parameters")]
		[XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Color BandAreaColor
		{
			get { return bandAreaColor; }
			set { bandAreaColor = value; }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private DynamicSR_ColorBand[] cacheDynamicSR_ColorBand = null;

        private static DynamicSR_ColorBand checkDynamicSR_ColorBand = new DynamicSR_ColorBand();

        /// <summary>
        /// Plots the dynamic support/resistance
        /// </summary>
        /// <returns></returns>
        public DynamicSR_ColorBand DynamicSR_ColorBand(bool bandArea, Color bandAreaColor, int period)
        {
            return DynamicSR_ColorBand(Input, bandArea, bandAreaColor, period);
        }

        /// <summary>
        /// Plots the dynamic support/resistance
        /// </summary>
        /// <returns></returns>
        public DynamicSR_ColorBand DynamicSR_ColorBand(Data.IDataSeries input, bool bandArea, Color bandAreaColor, int period)
        {
            checkDynamicSR_ColorBand.BandArea = bandArea;
            bandArea = checkDynamicSR_ColorBand.BandArea;
            checkDynamicSR_ColorBand.BandAreaColor = bandAreaColor;
            bandAreaColor = checkDynamicSR_ColorBand.BandAreaColor;
            checkDynamicSR_ColorBand.Period = period;
            period = checkDynamicSR_ColorBand.Period;

            if (cacheDynamicSR_ColorBand != null)
                for (int idx = 0; idx < cacheDynamicSR_ColorBand.Length; idx++)
                    if (cacheDynamicSR_ColorBand[idx].BandArea == bandArea && cacheDynamicSR_ColorBand[idx].BandAreaColor == bandAreaColor && cacheDynamicSR_ColorBand[idx].Period == period && cacheDynamicSR_ColorBand[idx].EqualsInput(input))
                        return cacheDynamicSR_ColorBand[idx];

            DynamicSR_ColorBand indicator = new DynamicSR_ColorBand();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.BandArea = bandArea;
            indicator.BandAreaColor = bandAreaColor;
            indicator.Period = period;
            indicator.SetUp();

            DynamicSR_ColorBand[] tmp = new DynamicSR_ColorBand[cacheDynamicSR_ColorBand == null ? 1 : cacheDynamicSR_ColorBand.Length + 1];
            if (cacheDynamicSR_ColorBand != null)
                cacheDynamicSR_ColorBand.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheDynamicSR_ColorBand = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Plots the dynamic support/resistance
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.DynamicSR_ColorBand DynamicSR_ColorBand(bool bandArea, Color bandAreaColor, int period)
        {
            return _indicator.DynamicSR_ColorBand(Input, bandArea, bandAreaColor, period);
        }

        /// <summary>
        /// Plots the dynamic support/resistance
        /// </summary>
        /// <returns></returns>
        public Indicator.DynamicSR_ColorBand DynamicSR_ColorBand(Data.IDataSeries input, bool bandArea, Color bandAreaColor, int period)
        {
            return _indicator.DynamicSR_ColorBand(input, bandArea, bandAreaColor, period);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Plots the dynamic support/resistance
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.DynamicSR_ColorBand DynamicSR_ColorBand(bool bandArea, Color bandAreaColor, int period)
        {
            return _indicator.DynamicSR_ColorBand(Input, bandArea, bandAreaColor, period);
        }

        /// <summary>
        /// Plots the dynamic support/resistance
        /// </summary>
        /// <returns></returns>
        public Indicator.DynamicSR_ColorBand DynamicSR_ColorBand(Data.IDataSeries input, bool bandArea, Color bandAreaColor, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.DynamicSR_ColorBand(input, bandArea, bandAreaColor, period);
        }

    }
}
#endregion
